@@ -80,7 +80,7 @@ class MYSQLExporter(Result):
     def save(self, query, args, status=True):
         try:
             if self.args.get_only_ff:
-                args=[args[0], args[1])
+                args=[args[0], args[1]]
             self.sqlconn.cursor().execute(query %tuple(args))
             self.sqlconn.commit()
 
